using ArgParse

function parse_commandline()
   args = ArgParseSettings()

    @add_arg_table args begin
    "--tol"
        help = "set numerical tolerance for the SDP solver"
        arg_type = Float64
        default = 1e-14
    "--iterations"
        help = "set maximal number of iterations for the SDP solver (default: 20000)"
        arg_type = Int
        default = 60000
    "--upper-bound"
        help = "Set an upper bound for the spectral gap"
        arg_type = Float64
        default = Inf
    "--cpus"
        help = "Set number of cpus used by solver (default: auto)"
        arg_type = Int
        required = false
    "--radius"
        help = "Radius of ball B_r(e,S) to find solution over"
        arg_type = Int
        default = 2
    "--warmstart"
        help = "Use warmstart.jl as the initial guess for SCS"
        action = :store_true
    "-MCG"
        help = "Compute for mapping class group of surface of genus N"
        arg_type = Int
        required = false
    "--Higman"
        help = "Compute for Higman Group"
        action = :store_true
    "--Caprace"
        help = "Compute for Higman Group"
        action = :store_true
    end

    return parse_args(args)
end
const PARSEDARGS = parse_commandline()

using AbstractAlgebra
using PropertyT
using Groups

include("CPUselect.jl")
set_parallel_mthread(PARSEDARGS, workers=false)

include("main_gapgroup.jl")

if PARSEDARGS["Caprace"]
    include("groups/caprace.jl")
    main(CapraceGroup, PARSEDARGS)

elseif PARSEDARGS["Higman"]
    include("groups/higman.jl")
    main(HigmanGroup, PARSEDARGS)

elseif PARSEDARGS["N"] != nothing
    include("groups/mappingclassgroup.jl")
    main(MappingClassGroups, PARSEDARGS)

else
    warn("You need to specify one of the --Higman, --Caprace, -MCG N")
end
