using SCS.SCSSolver
# using Mosek
# using CSDP
# using SDPA

include("FPGroups_GAP.jl")

function main(GROUP, parsed_args)

    radius = parsed_args["radius"]
    tol = parsed_args["tol"]
    iterations = parsed_args["iterations"]
    upper_bound = parsed_args["upper-bound"]
    warm = parsed_args["warmstart"]

    name, N = GROUP.groupname(parsed_args)
    G, S = GROUP.generatingset(N)

    isdir(name) || mkdir(name)
    logger = PropertyT.setup_logging(joinpath(name, "$(upper_bound)"), :fulllog)

    relations = [k*inv(v) for (k,v) in G.rels]
    prepare_pm_delta(name, GAP_groupcode(S, relations), radius)

    S = unique([S; inv.(S)])

    info(logger, "Group:       $name")
    info(logger, "Iterations:  $iterations")
    info(logger, "Precision:   $tol")
    info(logger, "Upper bound: $upper_bound")
    info(logger, "Radius:      $radius")
    info(logger, "Threads:     $(Threads.nthreads())")
    info(logger, "Workers:     $(workers())")
    info(logger, G)
    info(logger, "Symmetric generating set of size $(length(S))")

    solver = SCSSolver(eps=tol, max_iters=iterations, linearsolver=SCS.Direct, alpha=1.95, acceleration_lookback=1)

    return PropertyT.check_property_T(name, S, G(), solver, upper_bound, tol, radius, warm)
end
